==> knetdockapp_0.67.5.3.orig.tar.gz: knetdockapp-0.67.5.3/src/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by yodor   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/



#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>

#include "knetdockapp.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

static const char description[] = I18N_NOOP("A KDE Application for monitoring network link status and activity");

static const char version[] = "0.67.5.2";


int main(int argc, char **argv)
{
    KAboutData about("knetdockapp", I18N_NOOP("knetdockapp"), version, description,
                     KAboutData::License_GPL, "(C) 2005 Todor Aleksandrov", 0, 0, "yodor@developer.bg");
    about.addAuthor( "Todor Aleksandrov", 0, "yodor@developer.bg" );
    KCmdLineArgs::init(argc, argv, &about);
	KNetDockApp::addCmdLineOptions();
	KNetDockApp a;
	a.setAboutData(&about);
    return a.exec();

}

==> knetdockapp_0.82.orig.tar.gz: knetdockapp-0.82/src/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "knetdockapp.h"


#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>


static const char description[] =
    I18N_NOOP("A KDE Network Monitor");

static const char version[] = "0.82";

static KCmdLineOptions options[] =
{
//    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
    KCmdLineLastOption
};

int main(int argc, char **argv)
{
	KAboutData about("knetdockapp", I18N_NOOP("KNetDockApp"), version, description,
				KAboutData::License_GPL, "(C) 2007 Todor Gyumyushev", 0, 0, "yodor@developer.bg");
	about.addAuthor( "Todor Gyumyushev", 0, "yodor@developer.bg" );
	
	KCmdLineArgs::init(argc, argv, &about);
	KCmdLineArgs::addCmdLineOptions( options );

	//if (!KNetDockApp::start()) exit(0);

	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
	KNetDockApp app;	
	app.newInstance();
	args->clear();
	return app.exec();
}
